@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::DAGOLDEN;
 # ABSTRACT: Dist::Zilla configuration the way DAGOLDEN does it
-our $VERSION = '0.063'; # VERSION
+our $VERSION = '0.064'; # VERSION
 
 # Dependencies
 use Moose 0.99;
@@ -28,7 +28,7 @@ use Dist::Zilla::Plugin::GithubMeta 0.36       ();
 use Dist::Zilla::Plugin::InsertCopyright 0.001 ();
 use Dist::Zilla::Plugin::MetaNoIndex ();
 use Dist::Zilla::Plugin::MetaProvides::Package 1.14 (); # hides private packages
-use Dist::Zilla::Plugin::MinimumPerl ();
+use Dist::Zilla::Plugin::MinimumPerlFast ();
 use Dist::Zilla::Plugin::OurPkgVersion 0.004 ();        # TRIAL comment support
 use Dist::Zilla::Plugin::PodWeaver ();
 use Dist::Zilla::Plugin::PromptIfStale 0.011           ();
@@ -302,7 +302,7 @@ sub configure {
                 do_munging => 0,
             }
         ],
-        'MinimumPerl',
+        'MinimumPerlFast',
         (
             $self->auto_prereq
             ? [ 'AutoPrereqs' => { skip => "^t::lib" } ]
@@ -446,7 +446,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.063
+version 0.064
 
 =head1 SYNOPSIS
 
@@ -511,7 +511,7 @@ following dist.ini:
   authority = cpan:DAGOLDEN
   do_munging = 0
 
-  [MinimumPerl]       ; determine minimum perl version
+  [MinimumPerlFast]   ; determine minimum perl version
 
   [MetaNoIndex]       ; sets 'no_index' in META
   directory = t
@@ -597,78 +597,78 @@ the following options:
 
 =item *
 
-C<is_task> — this indicates whether C<TaskWeaver> or C<PodWeaver> should be used.
+C<is_task> â this indicates whether C<TaskWeaver> or C<PodWeaver> should be used.
 
 Default is 0.
 
 =item *
 
-C<authority> — specifies the C<x_authority> field for pause.  Defaults to 'cpan:DAGOLDEN'.
+C<authority> â specifies the C<x_authority> field for pause.  Defaults to 'cpan:DAGOLDEN'.
 
 =item *
 
-C<auto_prereq> — this indicates whether C<AutoPrereqs> should be used or not.  Default is 1.
+C<auto_prereq> â this indicates whether C<AutoPrereqs> should be used or not.  Default is 1.
 
 =item *
 
-C<darkpan> — for private code; uses C<FakeRelease> and fills in dummy repo/bugtracker data
+C<darkpan> â for private code; uses C<FakeRelease> and fills in dummy repo/bugtracker data
 
 =item *
 
-C<fake_release> — swaps C<FakeRelease> for C<UploadToCPAN>. Mostly useful for testing a dist.ini without risking a real release.
+C<fake_release> â swaps C<FakeRelease> for C<UploadToCPAN>. Mostly useful for testing a dist.ini without risking a real release.
 
 =item *
 
-C<git_remote> — where to push after release
+C<git_remote> â where to push after release
 
 =item *
 
-C<github_issues> — whether to use github issue tracker. Defaults is 1.
+C<github_issues> â whether to use github issue tracker. Defaults is 1.
 
 =item *
 
-C<stopwords> — add stopword for C<Test::PodSpelling> (can be repeated)
+C<stopwords> â add stopword for C<Test::PodSpelling> (can be repeated)
 
 =item *
 
-C<tag_format> — given to C<Git::Tag>.  Default is 'release-%v' to be more
+C<tag_format> â given to C<Git::Tag>.  Default is 'release-%v' to be more
 
 robust than just the version number when parsing versions for
 L<Git::NextVersion>
 
 =item *
 
-C<weaver_config> — specifies a L<Pod::Weaver> bundle.  Defaults to @DAGOLDEN.
+C<weaver_config> â specifies a L<Pod::Weaver> bundle.  Defaults to @DAGOLDEN.
 
 =item *
 
-C<version_regexp> — given to L<Git::NextVersion>.  Default
+C<version_regexp> â given to L<Git::NextVersion>.  Default
 
 is '^release-(.+)$'
 
 =item *
 
-C<no_git> — bypass all git-dependent plugins
+C<no_git> â bypass all git-dependent plugins
 
 =item *
 
-C<no_critic> — omit C<Test::Perl::Critic> tests
+C<no_critic> â omit C<Test::Perl::Critic> tests
 
 =item *
 
-C<no_spellcheck> — omit C<Test::PodSpelling> tests
+C<no_spellcheck> â omit C<Test::PodSpelling> tests
 
 =item *
 
-C<no_coverage> — omit PodCoverage tests
+C<no_coverage> â omit PodCoverage tests
 
 =item *
 
-C<no_minimum_perl> — omit C<Test::MinimumVersion> tests
+C<no_minimum_perl> â omit C<Test::MinimumVersion> tests
 
 =item *
 
-C<no_bugtracker> — DEPRECATED
+C<no_bugtracker> â DEPRECATED
 
 =back
 
